<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       *
 * @since      1.0.0
 *
 * @package    Habu
 * @subpackage Habu/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Habu
 * @subpackage Habu/public
 * @author     Habu <wpsupport@habu.com>
 */
class Habu_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Habu_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Habu_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style(
		    $this->plugin_name,
		    plugin_dir_url( __FILE__ ) . 'css/habu-public.css',
		    array(),
		    $this->version,
		    'all'
		);

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Habu_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Habu_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script(
		    $this->plugin_name,
		    plugin_dir_url( __FILE__ ) . 'js/habu-public.js',
		    array( 'jquery' ),
		    $this->version,
		    false
		);

	}


	public function show_post_id() {

        /**
         *
         * This function prevents showing a post-id for post list views.
         * ONLY creates a meta tag for single posts.
         *
         */

        global $post;
        $post_id = $post->ID;

        ?>
           <?php if (is_single()){
                 echo '<meta name="post-id" content="'.$post_id.'">'; }
                 elseif(!is_single()){ ' ';}
            ?>
        <?php
    }



    public function list_categories() {

        /**
         *
         * This function lists the posts' categories separated by a comma.
         *
         */

        $categories = array();

        ?>
            <?php
                foreach (get_the_category($post_id) as $c) {
                    $cat = get_category($c);
                    array_push($categories, $cat->name);
                }

                if (sizeOf($categories) > 0) {
                    $post_categories = implode(', ', $categories);
                } else {
                    $post_categories = 'Not Assigned';
                }
                echo '<meta name="categories" content="'.$post_categories.'">';
            ?>
        <?php
    }

}
